@@ -702,73 +702,75 @@ void dump_links (int z)
       tputs(dcc[z].sock,x,l);
    }
    context;
-   /* dump party line members */
-   for (i = 0; i < dcc_total; i++) {
-      if (dcc[i].type == &DCC_CHAT) {
-	 if ((dcc[i].u.chat->channel >= 0) && 
-	     (dcc[i].u.chat->channel < 100000)) {
+   if (!(bot_flags(dcc[z].user) & BOT_ISOLATE)) {
+      /* dump party line members */
+      for (i = 0; i < dcc_total; i++) {
+	 if (dcc[i].type == &DCC_CHAT) {
+	    if ((dcc[i].u.chat->channel >= 0) && 
+		(dcc[i].u.chat->channel < 100000)) {
 #ifndef NO_OLD_BOTNET
-	    if (b_numver(z) < NEAT_BOTNET) 
-	      l = simple_sprintf(x, "join %s %s %d %c%d %s\n",
-				 botnetnick, dcc[i].nick,
-				 dcc[i].u.chat->channel, geticon(i),
-				 dcc[i].sock, dcc[i].host);
-	    else 
+	       if (b_numver(z) < NEAT_BOTNET) 
+		 l = simple_sprintf(x, "join %s %s %d %c%d %s\n",
+				    botnetnick, dcc[i].nick,
+				    dcc[i].u.chat->channel, geticon(i),
+				    dcc[i].sock, dcc[i].host);
+	       else 
 #endif
-	      l = simple_sprintf(x, "j !%s %s %D %c%D %s\n",
-				 botnetnick, dcc[i].nick,
-				 dcc[i].u.chat->channel, geticon(i),
-				 dcc[i].sock, dcc[i].host);
-	    tputs(dcc[z].sock, x, l);
+		 l = simple_sprintf(x, "j !%s %s %D %c%D %s\n",
+				    botnetnick, dcc[i].nick,
+				    dcc[i].u.chat->channel, geticon(i),
+				    dcc[i].sock, dcc[i].host);
+	       tputs(dcc[z].sock, x, l);
 #ifndef NO_OLD_BOTNET
-	    if (b_numver(z) < NEAT_BOTNET) {
-	       if (dcc[i].u.chat->away) {
-		  l = simple_sprintf(x,"away %s %d %s\n", botnetnick,
-				     dcc[i].sock, dcc[i].u.chat->away);
+	       if (b_numver(z) < NEAT_BOTNET) {
+		  if (dcc[i].u.chat->away) {
+		     l = simple_sprintf(x,"away %s %d %s\n", botnetnick,
+					dcc[i].sock, dcc[i].u.chat->away);
 		  tputs(dcc[z].sock, x, l);
-	       }
-	       l = simple_sprintf(x,"idle %s %d %d\n", botnetnick,
-				  dcc[i].sock, now - dcc[i].timeval);
-	    } else 
+		  }
+		  l = simple_sprintf(x,"idle %s %d %d\n", botnetnick,
+				     dcc[i].sock, now - dcc[i].timeval);
+	       } else 
 #endif
-	      l = simple_sprintf(x,"i %s %D %D %s\n", botnetnick,
-				 dcc[i].sock, now - dcc[i].timeval, 
-				 dcc[i].u.chat->away ? dcc[i].u.chat->away : "");
-	    tputs(dcc[z].sock, x, l);
-	 }
-      }
-   }
-   context;
-   for (i = 0; i < parties; i++) {
-#ifndef NO_OLD_BOTNET
-	    if (b_numver(z) < NEAT_BOTNET) 
-	      l = simple_sprintf(x, "join %s %s %d %c%d %s\n",
-				 party[i].bot, party[i].nick,
-				 party[i].chan, party[i].flag,
-				 party[i].sock, party[i].from);
-	    else 
-#endif
-	      l = simple_sprintf(x, "j %s %s %D %c%D %s\n",
-				 party[i].bot, party[i].nick,
-				 party[i].chan, party[i].flag,
-				 party[i].sock, party[i].from);
-      tputs(dcc[z].sock, x, l);
-      if ((party[i].status & PLSTAT_AWAY) || (party[i].timer != 0)) {
-#ifndef NO_OLD_BOTNET
-	 if (b_numver(z) < NEAT_BOTNET) {
-	    if (party[i].status & PLSTAT_AWAY) {
-	       l = simple_sprintf(x,"away %s %d %s\n", party[i].bot,
-				  party[i].sock, party[i].away);
+		 l = simple_sprintf(x,"i %s %D %D %s\n", botnetnick,
+				    dcc[i].sock, now - dcc[i].timeval, 
+				    dcc[i].u.chat->away ? dcc[i].u.chat->away : "");
 	       tputs(dcc[z].sock, x, l);
 	    }
-	    l = simple_sprintf(x,"idle %s %d %d\n", party[i].bot,
-			       party[i].sock, now - party[i].timer);
-	 } else 
+	 }
+      }
+      context;
+      for (i = 0; i < parties; i++) {
+#ifndef NO_OLD_BOTNET
+	 if (b_numver(z) < NEAT_BOTNET) 
+	   l = simple_sprintf(x, "join %s %s %d %c%d %s\n",
+			      party[i].bot, party[i].nick,
+			      party[i].chan, party[i].flag,
+			      party[i].sock, party[i].from);
+	 else 
 #endif
-	   l = simple_sprintf(x,"i %s %D %D %s\n", party[i].bot,
-			      party[i].sock, now - party[i].timer, 
-			      party[i].away ? party[i].away : "");
+	   l = simple_sprintf(x, "j %s %s %D %c%D %s\n",
+			      party[i].bot, party[i].nick,
+			      party[i].chan, party[i].flag,
+			      party[i].sock, party[i].from);
 	 tputs(dcc[z].sock, x, l);
+	 if ((party[i].status & PLSTAT_AWAY) || (party[i].timer != 0)) {
+#ifndef NO_OLD_BOTNET
+	    if (b_numver(z) < NEAT_BOTNET) {
+	       if (party[i].status & PLSTAT_AWAY) {
+		  l = simple_sprintf(x,"away %s %d %s\n", party[i].bot,
+				     party[i].sock, party[i].away);
+		  tputs(dcc[z].sock, x, l);
+	       }
+	       l = simple_sprintf(x,"idle %s %d %d\n", party[i].bot,
+				  party[i].sock, now - party[i].timer);
+	    } else 
+#endif
+	      l = simple_sprintf(x,"i %s %D %D %s\n", party[i].bot,
+				 party[i].sock, now - party[i].timer, 
+				 party[i].away ? party[i].away : "");
+	    tputs(dcc[z].sock, x, l);
+	 }
       }
    }
    context;
