@@ -574,8 +574,7 @@ static void cmd_boot (struct userrec * u, int idx, char * par)
       dprintf(idx, "Who?  No such person on the party line.\n");
 }
 
-static void cmd_console (struct userrec * u, int idx, char * par)
-{
+static void cmd_console (struct userrec * u, int idx, char * par) {
    char * nick, s[2], s1[512];
    int dest = 0, i, ok = 0, pls, md;
    struct flag_record fr = {FR_GLOBAL|FR_CHAN,0,0,0,0,0};
@@ -791,7 +790,8 @@ static void cmd_nick (struct userrec * u, int idx, char * par)
      if ((newnick[i] <= 32) || (newnick[i] >= 127) || (newnick[i] == '@'))
        newnick[i] = '?';
    if (strchr("-,+*=:!.@#;$", newnick[0]) != NULL) {
-      dprintf(idx, "Bizarre quantum forces prevent nicknames from starting with %c\n", par[0]);
+      dprintf(idx, "Bizarre quantum forces prevent nicknames from starting with '%c'\n",
+	      newnick[0]);
    } else if (get_user_by_handle(userlist, newnick) &&
 	      strcasecmp(dcc[idx].nick, newnick)) {
       dprintf(idx, "Somebody is already using %s.\n", newnick);
@@ -1422,15 +1422,15 @@ static void cmd_chattr (struct userrec * u, int idx, char * par)
    if (chan)
      putlog(LOG_CMDS, "*", "#%s# (%s) chattr %s %s",
 	    dcc[idx].nick, chan?chan->name:"*",hand, chg ? chg : "");
-   else if (chg)
-     putlog(LOG_CMDS, "*", "#%s# chattr %s %s", dcc[idx].nick, hand, chg);
    else
-     putlog(LOG_CMDS, "*", "#%s# chattr %s", dcc[idx].nick, hand);
+     putlog(LOG_CMDS, "*", "#%s# chattr %s %s", dcc[idx].nick, hand, 
+            chg ? chg : "");
 
    /* get current flags and display them */
    if (user.match & FR_GLOBAL) {
       user.match = FR_GLOBAL;
-      check_dcc_attrs(u2, of);
+      if (chg)
+         check_dcc_attrs(u2, of);
       get_user_flagrec(u2, &user,NULL);
       build_flags(work, &user, NULL);
       if (work[0] != '-') 
@@ -1442,7 +1442,8 @@ static void cmd_chattr (struct userrec * u, int idx, char * par)
       user.match = FR_CHAN;
       get_user_flagrec(u2, &user, par);
       user.chan &= ~BOT_SHARE;
-      check_dcc_chanattrs(u2, chan->name, user.chan, ocf);
+      if (chg)
+         check_dcc_chanattrs(u2, chan->name, user.chan, ocf);
       build_flags(work, &user, NULL);
       if (work[0] != '-') 
 	dprintf(idx, "Channel flags for %s on %s are now +%s\n", hand, 
@@ -1457,13 +1458,14 @@ static void cmd_chattr (struct userrec * u, int idx, char * par)
    }
 }
 
-static void cmd_botattr (struct userrec * u, int idx, char * par)
+static void cmd_botattr (struct userrec * u, int idx, char * par) 
 {
    char * hand, * chg = NULL, work[1024];
    struct chanset_t *chan = NULL;
    struct userrec * u2;
    struct flag_record pls = {0,0,0,0,0,0}, mns = {0,0,0,0,0,0},
      user = {0,0,0,0,0,0};
+   int idx2;
    
    if (!par[0]) {
       dprintf(idx, "Usage: botattr <handle> [changes] [channel]\n");
@@ -1475,6 +1477,13 @@ static void cmd_botattr (struct userrec * u, int idx, char * par)
       dprintf(idx, "No such bot!\n");
       return;
    }
+   for (idx2 = 0; idx2 < dcc_total; idx2++) 
+     if (!strcasecmp(dcc[idx2].nick, hand))
+       break;
+   if (idx2 != dcc_total) {
+      dprintf(idx, "You may not change the attributes of a linked bot.\n");
+      return;
+   }
    if ((par[0] != '#') && (par[0] != '&')) {
       chg = newsplit(&par);
       if (!par[0] && strpbrk(chg, "|&"))
@@ -1505,25 +1514,24 @@ static void cmd_botattr (struct userrec * u, int idx, char * par)
 	 mns.chan = 0;
       }
       if (!glob_owner(user)) {
-	 pls.bot &= ~(BOT_SHARE|BOT_PASSIVE);
-	 mns.bot &= ~(BOT_SHARE|BOT_PASSIVE);
+	 pls.bot &= ~(BOT_SHARE | BOT_GLOBAL);
+	 mns.bot &= ~(BOT_SHARE | BOT_GLOBAL);
       }
       user.match = FR_BOT|(chan ? FR_CHAN : 0);
       get_user_flagrec(u2,&user,par);
       user.bot = (user.bot | pls.bot) & ~mns.bot;
-      if (user.bot & BOT_SHARE)
-	user.bot &= ~BOT_ALT;
       if ((user.bot & BOT_SHARE) == BOT_SHARE)
 	user.bot &= ~BOT_SHARE;
       if (chan)
 	user.chan = (user.chan | pls.chan) & ~mns.chan;
       set_user_flagrec(u2,&user,par);
    }
-   if (chg)
-     putlog(LOG_CMDS, "*", "#%s# botattr %s %s", dcc[idx].nick, hand, chg,par);
+    if (chan)
+     putlog(LOG_CMDS, "*", "#%s# (%s) botattr %s %s",
+	    dcc[idx].nick, chan->name, hand, chg ? chg : "");
    else
-     putlog(LOG_CMDS, "*", "#%s# botattr %s %s", dcc[idx].nick, hand, par);
-
+      putlog(LOG_CMDS, "*", "#%s# botattr %s %s", dcc[idx].nick, hand, 
+	     chg ? chg : "");
    /* get current flags and display them */
    if (!chan || pls.bot || mns.bot) {
       user.match = FR_BOT;
@@ -1580,7 +1588,7 @@ static void cmd_chat (struct userrec * u, int idx, char * par)
 		 newchan = -1;
 	    }
 	    if (newchan < 0) {
-	       dprintf(idx, "No channel by the name.\n");
+	       dprintf(idx, "No channel by that name.\n");
 	       return;
 	    }
 	 } else
