@@ -581,58 +581,62 @@ void help_subst (char * s, char * nick, struct flag_record * flags,
       towrite = NULL;
       switch (chr) {
 	case 'b':
-	 if (glob_hilite(*flags)) 
-	   if (help_flags & HELP_IRC) {
-	      towrite = "\002";
-	   } else if (help_flags & HELP_BOLD) {
-	      help_flags &= ~HELP_BOLD;
-	      towrite = "\033[0m";
-	   } else {
-	      help_flags |= HELP_BOLD;
-	      towrite = "\033[1m";
-	   }
+	 if (glob_hilite(*flags)) {
+	    if (help_flags & HELP_IRC) {
+	       towrite = "\002";
+	    } else if (help_flags & HELP_BOLD) {
+	       help_flags &= ~HELP_BOLD;
+	       towrite = "\033[0m";
+	    } else {
+	       help_flags |= HELP_BOLD;
+	       towrite = "\033[1m";
+	    }
+	 }
 	 break;
 	case 'v':
-	 if (glob_hilite(*flags)) 
-	   if (help_flags & HELP_IRC) {
-	      towrite = "\026";
-	   } else if (help_flags & HELP_REV) {
-	      help_flags &= ~HELP_REV;
-	      towrite = "\033[0m";
-	   } else {
-	      help_flags |= HELP_REV;
-	      towrite = "\033[7m";
-	   }
+	 if (glob_hilite(*flags)) {
+	    if (help_flags & HELP_IRC) {
+	       towrite = "\026";
+	    } else if (help_flags & HELP_REV) {
+	       help_flags &= ~HELP_REV;
+	       towrite = "\033[0m";
+	    } else {
+	       help_flags |= HELP_REV;
+	       towrite = "\033[7m";
+	    }
+	 }
 	 break;
 	case '_':
-	 if (glob_hilite(*flags)) 
-	   if (help_flags & HELP_IRC) {
-	      towrite = "\037";
-	   } else if (help_flags & HELP_UNDER) {
-	      help_flags &= ~HELP_UNDER;
-	      towrite = "\033[0m"; 
-	   } else {
-	      help_flags |= HELP_UNDER;
-	      towrite = "\033[4m";
-	   }
+	 if (glob_hilite(*flags)) {
+	    if (help_flags & HELP_IRC) {
+	       towrite = "\037";
+	    } else if (help_flags & HELP_UNDER) {
+	       help_flags &= ~HELP_UNDER;
+	       towrite = "\033[0m"; 
+	    } else {
+	       help_flags |= HELP_UNDER;
+	       towrite = "\033[4m";
+	    }
+	 }
 	 break;
 	case 'f':
-	 if (glob_hilite(*flags))
-	   if (help_flags & HELP_FLASH) {
-	      if (help_flags & HELP_IRC) {
-		 towrite = "\002\037";
-	      } else {
-		 towrite = "\033[0m";
-	      }
-	      help_flags &= ~HELP_FLASH;
-	   } else {
-	      help_flags |= HELP_FLASH;
-	      if (help_flags & HELP_IRC) {
-		 towrite = "\037\002";
-	      } else {
-		 towrite = "\033[5m";
-	      }
-	   }
+	 if (glob_hilite(*flags)) {
+	    if (help_flags & HELP_FLASH) {
+	       if (help_flags & HELP_IRC) {
+		  towrite = "\002\037";
+	       } else {
+		  towrite = "\033[0m";
+	       }
+	       help_flags &= ~HELP_FLASH;
+	    } else {
+	       help_flags |= HELP_FLASH;
+	       if (help_flags & HELP_IRC) {
+		  towrite = "\037\002";
+	       } else {
+		  towrite = "\033[5m";
+	       }
+	    }
+	 }
 	 break;
 	case 'U':
 #ifdef HAVE_UNAME
