@@ -31,12 +31,17 @@ static assoc_t *assoc;
 static void botnet_send_assoc (int idx, int chan, char * nick,
                              char * buf) {
    char x[1024];
-   simple_sprintf(x,"%D %s %s", chan, nick ? nick : botnetnick, buf);
-   botnet_send_zapf_broad(idx,botnetnick,"assoc",x);
+   int idx2;
+   
+   simple_sprintf(x,"assoc %D %s %s", chan, nick, buf);
+   for (idx2 = 0; idx2 < dcc_total; idx2++) 
+     if ((dcc[idx2].type == &DCC_BOT) && (idx2 != idx)
+	 && (b_numver(idx2) >= NEAT_BOTNET)
+	 && !(bot_flags(dcc[idx2].user) & BOT_ISOLATE))
+       botnet_send_zapf(idx2, botnetnick, dcc[idx2].nick, x);
 }
 
-static int assoc_expmem()
-{
+static int assoc_expmem() {
    assoc_t *a = assoc;
    int size = 0;
 
@@ -54,20 +59,21 @@ static void link_assoc (char * bot, char * via) {
       int idx = nextbot(bot);
       assoc_t *a = assoc;
       
-      context;
-      while (a != NULL) {
-	 if (a->name[0]) {
-	    simple_sprintf(x,"assoc %D %s %s", a->channel, botnetnick,
-			   a->name);
-	    botnet_send_zapf(idx, botnetnick, dcc[idx].nick, x);
+      if (!(bot_flags(dcc[idx].user) & BOT_ISOLATE)) {
+	 context;
+	 while (a != NULL) {
+	    if (a->name[0]) {
+	       simple_sprintf(x,"assoc %D %s %s", a->channel, botnetnick,
+			      a->name);
+	       botnet_send_zapf(idx, botnetnick, dcc[idx].nick, x);
+	    }
+	    a = a->next;
 	 }
-	 a = a->next;
       }
    }
 }
 
-static void kill_assoc (int chan)
-{
+static void kill_assoc (int chan) {
    assoc_t *a = assoc, *last = NULL;
 
    context;
@@ -86,8 +92,7 @@ static void kill_assoc (int chan)
    }
 }
 
-static void kill_all_assoc()
-{
+static void kill_all_assoc() {
    assoc_t *a = assoc, *x;
 
    context;
@@ -99,8 +104,7 @@ static void kill_all_assoc()
    assoc = NULL;
 }
 
-static void add_assoc (char * name, int chan)
-{
+static void add_assoc (char * name, int chan) {
    assoc_t *a = assoc, *b, *old = NULL;
 
    context;
@@ -147,8 +151,7 @@ static void add_assoc (char * name, int chan)
       old->next = b;
 }
 
-static int get_assoc (char * name)
-{
+static int get_assoc (char * name) {
    assoc_t *a = assoc;
 
    context;
@@ -160,8 +163,7 @@ static int get_assoc (char * name)
    return -1;
 }
 
-static char *get_assoc_name (int chan)
-{
+static char *get_assoc_name (int chan) {
    assoc_t *a = assoc;
 
    context;
@@ -173,8 +175,7 @@ static char *get_assoc_name (int chan)
    return NULL;
 }
 
-static void dump_assoc (int idx)
-{
+static void dump_assoc (int idx) {
    assoc_t *a = assoc;
 
    context;
@@ -193,8 +194,7 @@ static void dump_assoc (int idx)
 }
 
 
-static int cmd_assoc (struct userrec * u, int idx, char * par)
-{
+static int cmd_assoc (struct userrec * u, int idx, char * par) {
    char * num;
    int chan;
 
@@ -234,9 +234,8 @@ static int cmd_assoc (struct userrec * u, int idx, char * par)
 	 dprintf(idx, "Okay, removed name for channel %s%d.\n",
 		 (chan < 100000) ? "" : "*", chan % 100000);
 	 chanout_but(-1,chan, "--- %s removed this channel's name.\n", dcc[idx].nick);
-	 if (chan < 100000) {
-	    botnet_send_assoc(-1, chan, dcc[idx].nick, "0");
-	 }
+	 if (chan < 100000) 
+	   botnet_send_assoc(-1, chan, dcc[idx].nick, "0");
 	 return 0;
       }
       if (strlen(par) > 20) {
@@ -252,15 +251,13 @@ static int cmd_assoc (struct userrec * u, int idx, char * par)
       dprintf(idx, "Okay, channel %s%d is '%s' now.\n",
 	      (chan < 100000) ? "" : "*", chan % 100000, par);
       chanout_but(-1,chan, "--- %s named this channel '%s'\n", dcc[idx].nick, par);
-      if (chan < 100000) {
-	 botnet_send_assoc(-1, chan , dcc[idx].nick, par);
-      }
+      if (chan < 100000) 
+	botnet_send_assoc(-1, chan , dcc[idx].nick, par);
    }
    return 0;
 }
 
-static int tcl_killassoc STDVAR
-{
+static int tcl_killassoc STDVAR {
    int chan;
    
    context;
@@ -279,8 +276,7 @@ static int tcl_killassoc STDVAR
    return TCL_OK;
 }
 
-static int tcl_assoc STDVAR
-{
+static int tcl_assoc STDVAR {
    int chan;
    char name[21], *p;
 
@@ -322,7 +318,7 @@ static void zapf_assoc (char * botnick, char * code, char * par) {
    int linking = 0, chan;
    
    context;
-   if (idx >= 0) {
+   if ((idx >= 0) && !(bot_flags(dcc[idx].user) & BOT_ISOLATE)) {
       if (!strcasecmp(dcc[idx].nick, botnick))
 	linking = b_status(idx) & STAT_LINKING;
       s = newsplit(&par);
@@ -353,8 +349,7 @@ static void zapf_assoc (char * botnick, char * code, char * par) {
 }
       
 /* a report on the module status */
-static void assoc_report (int idx, int details)
-{
+static void assoc_report (int idx, int details)  {
    assoc_t *a = assoc;
    int size = 0, count = 0;;
 
@@ -370,30 +365,25 @@ static void assoc_report (int idx, int details)
    }
 }
 
-static cmd_t mydcc[] =
-{
+static cmd_t mydcc[] = {
    {"assoc", "", cmd_assoc, NULL},
 };
 
-static cmd_t mybot[] =
-{
+static cmd_t mybot[] = {
    {"assoc", "", (Function) zapf_assoc, NULL},
 };
 
-static cmd_t mylink[] =
-{
+static cmd_t mylink[] = {
    {"*", "", (Function) link_assoc, "assoc"},
 };
 
-static tcl_cmds mytcl[] =
-{
+static tcl_cmds mytcl[] = {
    {"assoc", tcl_assoc},
    {"killassoc", tcl_killassoc},
    {0, 0}
 };
 
-static char *assoc_close()
-{
+static char *assoc_close() {
    context;
    rem_builtins(H_dcc, mydcc,1);
    rem_builtins(H_bot, mybot,1);
@@ -406,16 +396,14 @@ static char *assoc_close()
 
 char *assoc_start ();
 
-static Function assoc_table[] =
-{
+static Function assoc_table[] = {
    (Function) assoc_start,
    (Function) assoc_close,
    (Function) assoc_expmem,
    (Function) assoc_report,
 };
 
-char *assoc_start (Function * global_funcs)
-{
+char *assoc_start (Function * global_funcs) {
    global = global_funcs;
    context;
    module_register(MODULE_NAME, assoc_table, 2, 0);
