@@ -299,9 +299,13 @@ static void cmd_chinfo (struct userrec * u, int idx, char * par)
       dprintf(idx, "No such user.\n");
       return;
    }
-   if ((par[0] == '#') || (par[0] == '+') || (par[0] == '&'))
+   if ((par[0] == '#') || (par[0] == '+') || (par[0] == '&')) {
       chname = newsplit(&par);
-   else
+      if (!findchan(chname)) {
+         dprintf(idx, "No such channel.\n");
+         return;
+      }
+   } else
       chname = 0;
    if (u1->flags & USER_BOT) {
       dprintf(idx, "Useful only for users.\n");
@@ -322,7 +326,7 @@ static void cmd_chinfo (struct userrec * u, int idx, char * par)
    }
    putlog(LOG_CMDS, "*", "#%s# chinfo %s %s %s", dcc[idx].nick, handle, 
 	  chname?chname:par, chname?par:"");
-   if (strcasecmp(par, "none") == 0)
+   if (!strcasecmp(par, "none"))
       par[0] = 0;
    if (chname) {
       set_handle_chaninfo(userlist, handle, chname, par);
@@ -599,10 +603,11 @@ static void cmd_chaninfo (struct userrec * u, int idx, char * par) {
 	      (chan->status & CHAN_STOPNETHACK) ? '+' : '-',
 	      (chan->status & CHAN_REVENGE) ? '+' : '-',
 	      (chan->status & CHAN_SECRET) ? '+' : '-');
-      dprintf(idx, "     %cshared     %cautovoice    %ccycle\n", 
+      dprintf(idx, "     %cshared     %cautovoice    %ccycle        %cseen\n", 
 	      (chan->status & CHAN_SHARED) ? '+' : '-',
 	      channel_autovoice(chan) ? '+' : '-',
-	      channel_cycle(chan) ? '+' : '-');
+	      channel_cycle(chan) ? '+' : '-',
+              (chan->status & CHAN_SEEN) ? '+' : '-');
       dprintf(idx, "flood settings: chan ctcp join kick deop\n");
       dprintf(idx, "number:          %3d  %3d  %3d  %3d  %3d\n",
 	      chan->flood_pub_thr, chan->flood_ctcp_thr, chan->flood_join_thr,
