@@ -62,6 +62,7 @@
 #include "../module.h"
 #include "../../users.h"
 #include "../../chan.h"
+#include "../channels.mod/channels.h"
 
 static Function *global = NULL;
 static void wordshift();
@@ -99,9 +100,12 @@ static int pub_seen (char *nick, char *host, char *hand,
                                                 char *channel, char *text)  
 {
 char prefix[50];
+struct chanset_t *chan = findchan(channel);
 context;
-   sprintf(prefix, "PRIVMSG %s :", channel);
-   do_seen(DP_HELP, prefix, nick, hand, channel, text);
+   if ((chan != NULL) && channel_seen(chan)) {
+     sprintf(prefix, "PRIVMSG %s :", channel);
+     do_seen(DP_HELP, prefix, nick, hand, channel, text);
+   }
    return 0;
 }
 
@@ -596,15 +600,16 @@ struct xtra_key * xk;
       
       if (ue) 
 	for (xk = ue->u.extra; xk; xk=xk->next) 
-       if (xk->key && !strcasecmp(xk->key,field)) 
-	    if (xk->data[0] == '{' && xk->data[strlen(xk->data)-1] == '}'
-		&& strlen(xk->data) > 2) {
-	       strncpy(fixit, &xk->data[1], strlen(xk->data - 9));
-	       fixit[strlen(xk->data) - 2] = 0;
-	       return fixit;
-	    } else {
-	       return xk->data;
-	    }
+	  if (xk->key && !strcasecmp(xk->key,field)) {
+	     if (xk->data[0] == '{' && xk->data[strlen(xk->data)-1] == '}'
+		 && strlen(xk->data) > 2) {
+		strncpy(fixit, &xk->data[1], strlen(xk->data - 9));
+		fixit[strlen(xk->data) - 2] = 0;
+		return fixit;
+	     } else {
+		return xk->data;
+	     }
+	  }
    }
    return "";
 }
